/***************************************************************************
                          rfilecxf.h  -  description
                             -------------------
    begin                : Sun Nov 7 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : mustun@ribbonsoft.com
 ***************************************************************************/


#ifndef RFILECXF_H
#define RFILECXF_H

#include "rfilebase.h"

#include "rprgdef.h"

/**
 * Offers support for the font format of CAM Expert.
 * @author Andreas Mustun
 */

class RGraphic;

class RFileCxf : public RFileBase  {
public:
  RFileCxf(const QString& _name, RGraphic* _graphic);
  ~RFileCxf();

  bool load();
  bool readFromBuffer();
  bool save();

  void convertToFont();

private:
  RGraphic* graphic;
  int       numElements;
};

#endif










